@@ -11,7 +11,7 @@ from sqlite3 import Error
 from oauthlib.oauth1.rfc5849 import signature, parameters
 import pandas as pd
 import pytz
-from jupyterhub.services.auth import HubAuthenticated
+from jupyterhub.services.auth import HubOAuthenticated,HubOAuthCallbackHandler
 from jupyterhub.utils import url_path_join
 from lxml import etree
 import aiohttp
@@ -214,7 +214,7 @@ async def post_grade(user_id, grade, course, section, assignment):
         raise Exception(f"Problem Posting Grade to LTI:{ex}") from ex
 
 
-class GoferHandler(HubAuthenticated, tornado.web.RequestHandler):
+class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
     """
     This class handles the HTTP requests for this tornado instance
     """
@@ -240,6 +240,7 @@ class GoferHandler(HubAuthenticated, tornado.web.RequestHandler):
         using_test_user = False
         try:
             # Accept notebook submissions, saves, then grades them
+            
             user = self.get_current_user()
             log_info_csv("PRINT USER OBJ", course, section, assignment, str(user))
             if user is None:
@@ -396,10 +397,21 @@ def start_server():
     """
     tornado.options.parse_command_line()
 
+    # app = tornado.web.Application(
+    #     [(PREFIX, GoferHandler)]
+    # )
     app = tornado.web.Application(
-        [(PREFIX, GoferHandler)]
-    )
-        
+        [
+            (PREFIX, GoferHandler),
+            (
+                url_path_join(
+                    os.environ['JUPYTERHUB_SERVICE_PREFIX'], 'oauth_callback'
+                ),
+                HubOAuthCallbackHandler,
+            )
+        ],
+        cookie_secret=os.urandom(32))
+
     logger = logging.getLogger('tornado.application')
     file_handler = logging.FileHandler(SERVER_LOG_FILE)
     formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
